@@ -3,7 +3,7 @@ BEGIN {
   $Dist::Zilla::PluginBundle::SCHWIGON::AUTHORITY = 'cpan:SCHWIGON';
 }
 # ABSTRACT: Build your distributions like SCHWIGON does
-$Dist::Zilla::PluginBundle::SCHWIGON::VERSION = '0.017';
+$Dist::Zilla::PluginBundle::SCHWIGON::VERSION = '0.018';
 # (well actually like FLORA - as it is shamelessly stolen)
 
 use 5.008;
@@ -324,7 +324,7 @@ method configure {
     $self->add_plugins(qw(
         MetaConfig
         MetaJSON
-        MetaProvides::Class
+        MetaProvides::Package
         PkgVersion
         PodSyntaxTests
     ));
@@ -474,7 +474,7 @@ Steffen Schwigon <ss5@renormalist.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Steffen Schwigon.
+This software is copyright (c) 2016 by Steffen Schwigon.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
